@@ -1,4 +1,4 @@
-__version__ = '1.0.15'
+__version__ = '1.0.20'
 __author__ = 'arnold'
 
 import json
@@ -116,4 +116,6 @@ class TerraformQueryExtension(Extension):
             if(output["attributes"]["name"] == name):
                 if(value_name is not None):
                     return output["attributes"]["value"][value_name]
-                return output["attributes"]["value"]
+                else:
+                    print("Value is None")
+                    exit()
